/*
    send.h - Provide the send dialog and related routines
    Copyright (c) 1999,2006  Joey Schulze <joey@infodrom.org>

    This file is part of the Gerstensaft package.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111, USA.
*/

#ifndef __SEND_H__
#define __SEND_H__

#include <gtk/gtk.h>
#include "main.h"

struct s_send_data {
  int addrok;

  GtkWidget *dialog;
  GtkWidget *listbox;
  GtkCombo *addrinput;
  GtkWidget *comment;
  GtkWidget *sendbutton;
  GtkWidget *clearbutton;
  struct s_main_data *wdata;
};

void send_dialog (gpointer data);

gint send_history_add (const gchar *addr, GtkCombo *combo);

int sendmsg (const char *addr, char *text);

int sendmessage (const char *addr, char *text);

#endif /* __SEND_H__ */
